@@ -175,13 +175,21 @@ class ArrayAccessor:
         )
 
     @Appender(docstrings.adjacency_matrix_docstring, join="\n", indents=1)
-    def adjacency_matrix(self, edges="intersect", include_index=True):
+    def adjacency_matrix(self, *interval_arrays, edges="intersect", include_index=True):
         return graph.adjacency_matrix(
             self._interval_array,
+            *interval_arrays,
             edges=edges,
             include_index=include_index,
         )
 
+    @Appender(docstrings.bridge_docstring, join="\n", indents=1)
+    def bridge(self, threshold):
+        return intervalarray.bridge(
+            self._interval_array,
+            threshold,
+        )
+
 
 def _register_accessors():
     _register_accessor("piso", pd.IntervalIndex)(ArrayAccessor)
